@@ -174,7 +174,11 @@ impl Rule for MD004UnorderedListStyle {
                                     0 => '*',
                                     1 => '+',
                                     2 => '-',
-                                    _ => unreachable!(),
+                                    _ => {
+                                        // This should never happen as % 3 only returns 0, 1, or 2
+                                        // but fallback to asterisk for safety
+                                        '*'
+                                    }
                                 };
                                 if marker != expected_marker {
                                     let (line, col) = ctx.offset_to_line_col(offset);
@@ -184,8 +188,7 @@ impl Rule for MD004UnorderedListStyle {
                                         end_line: line,
                                         end_column: col + 1,
                                         message: format!(
-                                            "List marker '{}' does not match expected style '{}' for nesting level {}",
-                                            marker, expected_marker, nesting_level
+                                            "List marker '{marker}' does not match expected style '{expected_marker}' for nesting level {nesting_level}"
                                         ),
                                         severity: Severity::Warning,
                                         rule_name: Some(self.name()),
@@ -202,7 +205,11 @@ impl Rule for MD004UnorderedListStyle {
                                     UnorderedListStyle::Asterisk => '*',
                                     UnorderedListStyle::Dash => '-',
                                     UnorderedListStyle::Plus => '+',
-                                    _ => unreachable!(),
+                                    UnorderedListStyle::Consistent | UnorderedListStyle::Sublist => {
+                                        // These cases are handled separately above
+                                        // but fallback to asterisk for safety
+                                        '*'
+                                    }
                                 };
                                 if marker != target_marker {
                                     let (line, col) = ctx.offset_to_line_col(offset);
@@ -278,7 +285,11 @@ impl Rule for MD004UnorderedListStyle {
                                     0 => '*',
                                     1 => '+',
                                     2 => '-',
-                                    _ => unreachable!(),
+                                    _ => {
+                                        // This should never happen as % 3 only returns 0, 1, or 2
+                                        // but fallback to asterisk for safety
+                                        '*'
+                                    }
                                 }
                             }
                             UnorderedListStyle::Asterisk => '*',
@@ -660,9 +671,18 @@ mod tests {
         let ctx = LintContext::new(content);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 3);
-        assert_eq!(result[0].message, "List marker '-' does not match expected style '*' for nesting level 0");
-        assert_eq!(result[1].message, "List marker '*' does not match expected style '+' for nesting level 1");
-        assert_eq!(result[2].message, "List marker '+' does not match expected style '-' for nesting level 2");
+        assert_eq!(
+            result[0].message,
+            "List marker '-' does not match expected style '*' for nesting level 0"
+        );
+        assert_eq!(
+            result[1].message,
+            "List marker '*' does not match expected style '+' for nesting level 1"
+        );
+        assert_eq!(
+            result[2].message,
+            "List marker '+' does not match expected style '-' for nesting level 2"
+        );
     }
 
     #[test]
