@@ -2,8 +2,7 @@ use crate::utils::range_utils::LineIndex;
 
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::regex_cache::UNORDERED_LIST_MARKER_REGEX;
 
 /// Rule MD006: Consider starting bulleted lists at the leftmost column
 ///
@@ -16,15 +15,33 @@ use regex::Regex;
 #[derive(Clone)]
 pub struct MD006StartBullets;
 
-lazy_static! {
-    // Pattern to match bullet list items: captures indentation, marker, and space after marker
-    static ref BULLET_PATTERN: Regex = Regex::new(r"^(\s*)([*+-])(\s+)").unwrap();
-
-    // Pattern to match code fence markers
-    static ref CODE_FENCE_PATTERN: Regex = Regex::new(r"^(\s*)(```|~~~)").unwrap();
-}
-
 impl MD006StartBullets {
+    /// Check if a bullet is nested under an ordered list item
+    fn is_nested_under_ordered_item(
+        &self,
+        ctx: &crate::lint_context::LintContext,
+        current_line: usize,
+        current_indent: usize,
+    ) -> bool {
+        // Look backward from current line to find parent item
+        for line_idx in (1..current_line).rev() {
+            if let Some(line_info) = ctx.line_info(line_idx) {
+                if let Some(list_item) = &line_info.list_item {
+                    // Found a list item - check if it's at a lower indentation (parent level)
+                    if list_item.marker_column < current_indent {
+                        // This is a parent item - check if it's ordered
+                        return list_item.is_ordered;
+                    }
+                }
+                // If we encounter non-blank, non-list content at column 0, stop looking
+                else if !line_info.is_blank && line_info.indent == 0 {
+                    break;
+                }
+            }
+        }
+        false
+    }
+
     /// Optimized check using centralized list blocks
     fn check_optimized(&self, ctx: &crate::lint_context::LintContext) -> LintResult {
         let content = ctx.content;
@@ -56,21 +73,26 @@ impl MD006StartBullets {
                             // Top-level items are always valid
                             is_valid = true;
                         } else {
-                            // Check if this is a valid nested item
-                            match Self::find_relevant_previous_bullet(&lines, line_idx) {
-                                Some((prev_idx, prev_indent)) => {
-                                    match prev_indent.cmp(&indent) {
-                                        std::cmp::Ordering::Less | std::cmp::Ordering::Equal => {
-                                            // Valid nesting or sibling if previous item was valid
-                                            is_valid = valid_bullet_lines[prev_idx];
-                                        }
-                                        std::cmp::Ordering::Greater => {
-                                            // remains invalid
+                            // Check if this is nested under an ordered item with correct indentation (3 spaces)
+                            if indent == 3 && self.is_nested_under_ordered_item(ctx, item_line, indent) {
+                                is_valid = true;
+                            } else {
+                                // Check if this is a valid nested item under another bullet
+                                match Self::find_relevant_previous_bullet(&lines, line_idx) {
+                                    Some((prev_idx, prev_indent)) => {
+                                        match prev_indent.cmp(&indent) {
+                                            std::cmp::Ordering::Less | std::cmp::Ordering::Equal => {
+                                                // Valid nesting or sibling if previous item was valid
+                                                is_valid = valid_bullet_lines[prev_idx];
+                                            }
+                                            std::cmp::Ordering::Greater => {
+                                                // remains invalid
+                                            }
                                         }
                                     }
-                                }
-                                None => {
-                                    // Indented item with no previous bullet remains invalid
+                                    None => {
+                                        // Indented item with no previous bullet remains invalid
+                                    }
                                 }
                             }
                         }
@@ -84,7 +106,7 @@ impl MD006StartBullets {
 
                             // For the fix, we need to replace the highlighted part with just the bullet marker
                             let trimmed = line.trim_start();
-                            let bullet_part = if let Some(captures) = BULLET_PATTERN.captures(trimmed) {
+                            let bullet_part = if let Some(captures) = UNORDERED_LIST_MARKER_REGEX.captures(trimmed) {
                                 let marker = captures.get(2).map_or("*", |m| m.as_str());
                                 format!("{marker} ")
                             } else {
@@ -123,7 +145,7 @@ impl MD006StartBullets {
     }
     /// Checks if a line is a bullet list item and returns its indentation level
     fn is_bullet_list_item(line: &str) -> Option<usize> {
-        if let Some(captures) = BULLET_PATTERN.captures(line) {
+        if let Some(captures) = UNORDERED_LIST_MARKER_REGEX.captures(line) {
             if let Some(indent) = captures.get(1) {
                 return Some(indent.as_str().len());
             }
@@ -338,7 +360,7 @@ impl Rule for MD006StartBullets {
                     let line = lines[line_idx];
                     let trimmed = line.trim_start();
                     // Extract just the bullet marker and normalize to single space
-                    let bullet_part = if let Some(captures) = BULLET_PATTERN.captures(trimmed) {
+                    let bullet_part = if let Some(captures) = UNORDERED_LIST_MARKER_REGEX.captures(trimmed) {
                         format!("{} ", captures.get(2).unwrap().as_str()) // Always use single space
                     } else {
                         "* ".to_string() // fallback
@@ -453,4 +475,58 @@ mod tests {
             "Standard nesting (* Item ->   * Item) should NOT generate warnings, found: {result:?}"
         );
     }
+
+    #[test]
+    fn test_bullets_nested_under_numbered_items() {
+        let rule = MD006StartBullets;
+        let content = "\
+1. **Active Directory/LDAP**
+   - User authentication and directory services
+   - LDAP for user information and validation
+
+2. **Oracle Unified Directory (OUD)**
+   - Extended user directory services";
+        let ctx = crate::lint_context::LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+        // Should have no warnings - 3 spaces is valid for bullets under numbered items
+        assert!(
+            result.is_empty(),
+            "Expected no warnings for bullets with 3 spaces under numbered items, got: {result:?}"
+        );
+    }
+
+    #[test]
+    fn test_bullets_nested_under_numbered_items_wrong_indent() {
+        let rule = MD006StartBullets;
+        let content = "\
+1. **Active Directory/LDAP**
+  - Wrong: only 2 spaces
+    - Also wrong: 4 spaces";
+        let ctx = crate::lint_context::LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+        // Should flag the incorrect indentations
+        assert_eq!(
+            result.len(),
+            2,
+            "Expected warnings for bullets with incorrect spacing under numbered items"
+        );
+        assert!(result.iter().any(|w| w.line == 2));
+        assert!(result.iter().any(|w| w.line == 3));
+    }
+
+    #[test]
+    fn test_regular_bullet_nesting_still_works() {
+        let rule = MD006StartBullets;
+        let content = "\
+* Top level
+  * Nested bullet (2 spaces is correct)
+    * Deeply nested (4 spaces)";
+        let ctx = crate::lint_context::LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+        // Should have no warnings - standard bullet nesting still works
+        assert!(
+            result.is_empty(),
+            "Expected no warnings for standard bullet nesting, got: {result:?}"
+        );
+    }
 }
