@@ -5,35 +5,14 @@ use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severi
 use crate::rule_config_serde::RuleConfig;
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
 use crate::utils::range_utils::calculate_excess_range;
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::regex_cache::{
+    IMAGE_REF_PATTERN, INLINE_LINK_REGEX as MARKDOWN_LINK_PATTERN, LINK_REF_PATTERN, URL_IN_TEXT, URL_PATTERN,
+};
 use toml;
 
 pub mod md013_config;
 use md013_config::MD013Config;
 
-lazy_static! {
-    static ref URL_PATTERN: Regex = Regex::new(r"^https?://\S+$").unwrap();
-    static ref IMAGE_REF_PATTERN: Regex = Regex::new(r"^!\[.*?\]\[.*?\]$" ).unwrap();
-    static ref LINK_REF_PATTERN: Regex = Regex::new(r"^\[.*?\]:\s*https?://\S+$").unwrap();
-
-    // Pattern to find URLs anywhere in text
-    static ref URL_IN_TEXT: Regex = Regex::new(r"https?://\S+").unwrap();
-
-    // Pattern to find markdown links [text](url) for URL exclusion
-    static ref MARKDOWN_LINK_PATTERN: Regex = Regex::new(r"\[([^\]]*)\]\(([^)]+)\)").unwrap();
-
-    // Sentence splitting patterns
-    static ref SENTENCE_END: Regex = Regex::new(r"[.!?]\s+[A-Z]").unwrap();
-    static ref ABBREVIATION: Regex = Regex::new(r"\b(?:Mr|Mrs|Ms|Dr|Prof|Sr|Jr|vs|etc|i\.e|e\.g|Inc|Corp|Ltd|Co|St|Ave|Blvd|Rd|Ph\.D|M\.D|B\.A|M\.A|Ph\.D|U\.S|U\.K|U\.N|N\.Y|L\.A|D\.C)\.\s+[A-Z]").unwrap();
-    static ref DECIMAL_NUMBER: Regex = Regex::new(r"\d+\.\s*\d+").unwrap();
-    static ref LIST_ITEM: Regex = Regex::new(r"^\s*\d+\.\s+").unwrap();
-
-    // Link detection patterns
-    static ref INLINE_LINK: Regex = Regex::new(r"\[([^\]]*)\]\(([^)]*)\)").unwrap();
-    static ref REFERENCE_LINK: Regex = Regex::new(r"\[([^\]]*)\]\[([^\]]*)\]").unwrap();
-}
-
 #[derive(Clone, Default)]
 pub struct MD013LineLength {
     config: MD013Config,
@@ -51,6 +30,7 @@ impl MD013LineLength {
                 heading_line_length: None,
                 code_block_line_length: None,
                 stern: false,
+                enable_reflow: false,
             },
         }
     }
@@ -135,15 +115,17 @@ impl Rule for MD013LineLength {
         if content.is_empty() {
             return Ok(Vec::new());
         }
-        
+
         // Quick check: if total content is shorter than line limit, definitely no violations
         if content.len() <= self.config.line_length {
             return Ok(Vec::new());
         }
-        
+
         // More aggressive early return - check if any line could possibly be long
         let has_long_lines = if !ctx.lines.is_empty() {
-            ctx.lines.iter().any(|line| line.content.len() > self.config.line_length)
+            ctx.lines
+                .iter()
+                .any(|line| line.content.len() > self.config.line_length)
         } else {
             // Fallback: do a quick scan for newlines to estimate max line length
             let mut max_line_len = 0;
@@ -159,12 +141,12 @@ impl Rule for MD013LineLength {
             max_line_len = max_line_len.max(current_line_len);
             max_line_len > self.config.line_length
         };
-        
+
         if !has_long_lines {
             return Ok(Vec::new());
         }
 
-        // Create structure manually 
+        // Create structure manually
         let structure = DocumentStructure::new(content);
         self.check_with_structure(ctx, &structure)
     }
@@ -177,9 +159,49 @@ impl Rule for MD013LineLength {
     ) -> LintResult {
         let content = ctx.content;
         let mut warnings = Vec::new();
-        
+
         // Early return was already done in check(), so we know there are long lines
-        
+
+        // Check for inline configuration overrides
+        let inline_config = crate::inline_config::InlineConfig::from_content(content);
+        let config_override = inline_config.get_rule_config("MD013");
+
+        // Apply configuration override if present
+        let effective_config = if let Some(json_config) = config_override {
+            if let Some(obj) = json_config.as_object() {
+                let mut config = self.config.clone();
+                if let Some(line_length) = obj.get("line_length").and_then(|v| v.as_u64()) {
+                    config.line_length = line_length as usize;
+                }
+                if let Some(code_blocks) = obj.get("code_blocks").and_then(|v| v.as_bool()) {
+                    config.code_blocks = code_blocks;
+                }
+                if let Some(tables) = obj.get("tables").and_then(|v| v.as_bool()) {
+                    config.tables = tables;
+                }
+                if let Some(headings) = obj.get("headings").and_then(|v| v.as_bool()) {
+                    config.headings = headings;
+                }
+                if let Some(strict) = obj.get("strict").and_then(|v| v.as_bool()) {
+                    config.strict = strict;
+                }
+                if let Some(stern) = obj.get("stern").and_then(|v| v.as_bool()) {
+                    config.stern = stern;
+                }
+                if let Some(heading_line_length) = obj.get("heading_line_length").and_then(|v| v.as_u64()) {
+                    config.heading_line_length = Some(heading_line_length as usize);
+                }
+                if let Some(code_block_line_length) = obj.get("code_block_line_length").and_then(|v| v.as_u64()) {
+                    config.code_block_line_length = Some(code_block_line_length as usize);
+                }
+                config
+            } else {
+                self.config.clone()
+            }
+        } else {
+            self.config.clone()
+        };
+
         // Use ctx.lines if available for better performance
         let lines: Vec<&str> = if !ctx.lines.is_empty() {
             ctx.lines.iter().map(|l| l.content.as_str()).collect()
@@ -194,20 +216,22 @@ impl Rule for MD013LineLength {
         let heading_lines_set: std::collections::HashSet<usize> = structure.heading_lines.iter().cloned().collect();
 
         // Pre-compute table lines for efficiency instead of calling is_in_table for each line
-        let table_lines_set: std::collections::HashSet<usize> = if self.config.tables {
+        let table_lines_set: std::collections::HashSet<usize> = if effective_config.tables {
             let mut table_lines = std::collections::HashSet::new();
             let mut in_table = false;
-            
+
             for (i, line) in lines.iter().enumerate() {
                 let line_number = i + 1;
-                
+
                 // Quick check if in code block using pre-computed blocks from context or structure
                 let in_code = if !ctx.code_blocks.is_empty() {
-                    ctx.code_blocks.iter().any(|(start, end)| *start <= line_number && line_number <= *end)
+                    ctx.code_blocks
+                        .iter()
+                        .any(|(start, end)| *start <= line_number && line_number <= *end)
                 } else {
                     structure.is_in_code_block(line_number)
                 };
-                
+
                 if !in_code && line.contains('|') {
                     in_table = true;
                     table_lines.insert(line_number);
@@ -227,14 +251,18 @@ impl Rule for MD013LineLength {
 
             // Calculate effective length excluding unbreakable URLs
             let effective_length = self.calculate_effective_length(line);
-            
+
             // Determine the appropriate line length limit based on line type
             let line_limit = if heading_lines_set.contains(&line_number) {
-                self.config.heading_line_length.unwrap_or(self.config.line_length)
+                effective_config
+                    .heading_line_length
+                    .unwrap_or(effective_config.line_length)
             } else if structure.is_in_code_block(line_number) {
-                self.config.code_block_line_length.unwrap_or(self.config.line_length)
+                effective_config
+                    .code_block_line_length
+                    .unwrap_or(effective_config.line_length)
             } else {
-                self.config.line_length
+                effective_config.line_length
             };
 
             // Skip short lines immediately
@@ -243,16 +271,20 @@ impl Rule for MD013LineLength {
             }
 
             // Skip various block types efficiently
-            if !self.config.strict && !self.config.stern {
+            if !effective_config.strict && !effective_config.stern {
                 // Skip setext heading underlines
                 if !line.trim().is_empty() && line.trim().chars().all(|c| c == '=' || c == '-') {
                     continue;
                 }
 
                 // Skip block elements according to config flags (optimized checks)
-                if (self.config.headings && heading_lines_set.contains(&line_number) && self.config.heading_line_length.is_none())
-                    || (!self.config.code_blocks && structure.is_in_code_block(line_number) && self.config.code_block_line_length.is_none())
-                    || (self.config.tables && table_lines_set.contains(&line_number))
+                if (effective_config.headings
+                    && heading_lines_set.contains(&line_number)
+                    && effective_config.heading_line_length.is_none())
+                    || (!effective_config.code_blocks
+                        && structure.is_in_code_block(line_number)
+                        && effective_config.code_block_line_length.is_none())
+                    || (effective_config.tables && table_lines_set.contains(&line_number))
                     || structure.is_in_blockquote(line_number)
                     || structure.is_in_html_block(line_number)
                 {
@@ -263,11 +295,15 @@ impl Rule for MD013LineLength {
                 if self.should_ignore_line(line, &lines, line_num, structure) {
                     continue;
                 }
-            } else if self.config.stern {
+            } else if effective_config.stern {
                 // In stern mode, only skip if explicitly configured
-                if (self.config.headings && heading_lines_set.contains(&line_number) && self.config.heading_line_length.is_none())
-                    || (!self.config.code_blocks && structure.is_in_code_block(line_number) && self.config.code_block_line_length.is_none())
-                    || (self.config.tables && table_lines_set.contains(&line_number))
+                if (effective_config.headings
+                    && heading_lines_set.contains(&line_number)
+                    && effective_config.heading_line_length.is_none())
+                    || (!effective_config.code_blocks
+                        && structure.is_in_code_block(line_number)
+                        && effective_config.code_block_line_length.is_none())
+                    || (effective_config.tables && table_lines_set.contains(&line_number))
                 {
                     continue;
                 }
@@ -303,20 +339,13 @@ impl Rule for MD013LineLength {
             };
 
             let message = if let Some(ref _fix_obj) = fix {
-                format!(
-                    "Line length {} exceeds {} characters (can trim whitespace)",
-                    effective_length, line_limit
-                )
+                format!("Line length {effective_length} exceeds {line_limit} characters (can trim whitespace)")
             } else {
-                format!(
-                    "Line length {} exceeds {} characters",
-                    effective_length, line_limit
-                )
+                format!("Line length {effective_length} exceeds {line_limit} characters")
             };
 
             // Calculate precise character range for the excess portion
-            let (start_line, start_col, end_line, end_col) =
-                calculate_excess_range(line_number, line, line_limit);
+            let (start_line, start_col, end_line, end_col) = calculate_excess_range(line_number, line, line_limit);
 
             warnings.push(LintWarning {
                 rule_name: Some(self.name()),
@@ -333,6 +362,18 @@ impl Rule for MD013LineLength {
     }
 
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
+        // If reflow is enabled, use the new text reflow functionality
+        if self.config.enable_reflow {
+            let reflow_options = crate::utils::text_reflow::ReflowOptions {
+                line_length: self.config.line_length,
+                break_on_sentences: true,
+                preserve_breaks: false,
+            };
+
+            return Ok(crate::utils::text_reflow::reflow_markdown(ctx.content, &reflow_options));
+        }
+
+        // Otherwise, use the existing fix logic (trimming whitespace)
         // Get all warnings with their fixes
         let warnings = self.check(ctx)?;
 
@@ -349,7 +390,7 @@ impl Rule for MD013LineLength {
                 break;
             }
         }
-        
+
         if !has_any_fix {
             return Ok(ctx.content.to_string());
         }
@@ -359,12 +400,12 @@ impl Rule for MD013LineLength {
             .iter()
             .filter_map(|w| w.fix.as_ref().map(|f| (f.range.start, f.range.end, &f.replacement)))
             .collect();
-        
+
         // This should not happen given our check above, but just in case
         if fixes.is_empty() {
             return Ok(ctx.content.to_string());
         }
-        
+
         fixes.sort_by(|a, b| b.0.cmp(&a.0));
 
         // Apply fixes from end to beginning to preserve byte offsets
@@ -395,14 +436,16 @@ impl Rule for MD013LineLength {
         if ctx.content.is_empty() {
             return true;
         }
-        
+
         // Quick check: if total content is shorter than line limit, definitely skip
         if ctx.content.len() <= self.config.line_length {
             return true;
         }
-        
+
         // Use more efficient check - any() with early termination instead of all()
-        !ctx.lines.iter().any(|line| line.content.len() > self.config.line_length)
+        !ctx.lines
+            .iter()
+            .any(|line| line.content.len() > self.config.line_length)
     }
 
     fn default_config_section(&self) -> Option<(String, toml::Value)> {
@@ -907,4 +950,159 @@ Another long line that should trigger a warning."#;
         // Should not flag because the URL is in a markdown link
         assert_eq!(result.len(), 0);
     }
+
+    #[test]
+    fn test_text_reflow_simple() {
+        let config = MD013Config {
+            line_length: 30,
+            enable_reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This is a very long line that definitely exceeds thirty characters and needs to be wrapped.";
+        let ctx = LintContext::new(content);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Verify all lines are under 30 chars
+        for line in fixed.lines() {
+            assert!(
+                line.chars().count() <= 30,
+                "Line too long: {} (len={})",
+                line,
+                line.chars().count()
+            );
+        }
+
+        // Verify content is preserved
+        let fixed_words: Vec<&str> = fixed.split_whitespace().collect();
+        let original_words: Vec<&str> = content.split_whitespace().collect();
+        assert_eq!(fixed_words, original_words);
+    }
+
+    #[test]
+    fn test_text_reflow_preserves_markdown_elements() {
+        let config = MD013Config {
+            line_length: 40,
+            enable_reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = "This paragraph has **bold text** and *italic text* and [a link](https://example.com) that should be preserved.";
+        let ctx = LintContext::new(content);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Verify markdown elements are preserved
+        assert!(fixed.contains("**bold text**"), "Bold text not preserved in: {fixed}");
+        assert!(fixed.contains("*italic text*"), "Italic text not preserved in: {fixed}");
+        assert!(
+            fixed.contains("[a link](https://example.com)"),
+            "Link not preserved in: {fixed}"
+        );
+
+        // Verify all lines are under 40 chars
+        for line in fixed.lines() {
+            assert!(line.len() <= 40, "Line too long: {line}");
+        }
+    }
+
+    #[test]
+    fn test_text_reflow_preserves_code_blocks() {
+        let config = MD013Config {
+            line_length: 30,
+            enable_reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = r#"Here is some text.
+
+```python
+def very_long_function_name_that_exceeds_limit():
+    return "This should not be wrapped"
+```
+
+More text after code block."#;
+        let ctx = LintContext::new(content);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Verify code block is preserved
+        assert!(fixed.contains("def very_long_function_name_that_exceeds_limit():"));
+        assert!(fixed.contains("```python"));
+        assert!(fixed.contains("```"));
+    }
+
+    #[test]
+    fn test_text_reflow_preserves_lists() {
+        let config = MD013Config {
+            line_length: 30,
+            enable_reflow: true,
+            ..Default::default()
+        };
+        let rule = MD013LineLength::from_config_struct(config);
+
+        let content = r#"Here is a list:
+
+1. First item with a very long line that needs wrapping
+2. Second item is short
+3. Third item also has a long line that exceeds the limit
+
+And a bullet list:
+
+- Bullet item with very long content that needs wrapping
+- Short bullet"#;
+        let ctx = LintContext::new(content);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Verify list structure is preserved
+        assert!(fixed.contains("1. "));
+        assert!(fixed.contains("2. "));
+        assert!(fixed.contains("3. "));
+        assert!(fixed.contains("- "));
+
+        // Verify proper indentation for wrapped lines
+        let lines: Vec<&str> = fixed.lines().collect();
+        for (i, line) in lines.iter().enumerate() {
+            if line.trim().starts_with("1.") || line.trim().starts_with("2.") || line.trim().starts_with("3.") {
+                // Check if next line is a continuation (should be indented with 3 spaces for numbered lists)
+                if i + 1 < lines.len()
+                    && !lines[i + 1].trim().is_empty()
+                    && !lines[i + 1].trim().starts_with(char::is_numeric)
+                    && !lines[i + 1].trim().starts_with("-")
+                {
+                    // Numbered list continuation lines should have 3 spaces
+                    assert!(lines[i + 1].starts_with("   ") || lines[i + 1].trim().is_empty());
+                }
+            } else if line.trim().starts_with("-") {
+                // Check if next line is a continuation (should be indented with 2 spaces for dash lists)
+                if i + 1 < lines.len()
+                    && !lines[i + 1].trim().is_empty()
+                    && !lines[i + 1].trim().starts_with(char::is_numeric)
+                    && !lines[i + 1].trim().starts_with("-")
+                {
+                    // Dash list continuation lines should have 2 spaces
+                    assert!(lines[i + 1].starts_with("  ") || lines[i + 1].trim().is_empty());
+                }
+            }
+        }
+    }
+
+    #[test]
+    fn test_text_reflow_disabled_by_default() {
+        let rule = MD013LineLength::new(30, false, false, false, false);
+
+        let content = "This is a very long line that definitely exceeds thirty characters.";
+        let ctx = LintContext::new(content);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Without reflow enabled, it should only trim whitespace (if any)
+        // Since there's no trailing whitespace, content should be unchanged
+        assert_eq!(fixed, content);
+    }
 }
