@@ -3,26 +3,14 @@
 /// See [docs/md025.md](../../docs/md025.md) for full documentation, configuration, and examples.
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::range_utils::{LineIndex, calculate_match_range};
-use lazy_static::lazy_static;
-use regex::Regex;
+use crate::utils::regex_cache::{
+    HR_ASTERISK, HR_DASH, HR_SPACED_ASTERISK, HR_SPACED_DASH, HR_SPACED_UNDERSCORE, HR_UNDERSCORE,
+};
 use toml;
 
 mod md025_config;
 use md025_config::MD025Config;
 
-lazy_static! {
-    // Pattern for quick check if content has any headings at all
-    static ref HEADING_CHECK: Regex = Regex::new(r"(?m)^(?:\s*)#").unwrap();
-
-    // Horizontal rule patterns (from MD035)
-    static ref HR_DASH: Regex = Regex::new(r"^\-{3,}\s*$").unwrap();
-    static ref HR_ASTERISK: Regex = Regex::new(r"^\*{3,}\s*$").unwrap();
-    static ref HR_UNDERSCORE: Regex = Regex::new(r"^_{3,}\s*$").unwrap();
-    static ref HR_SPACED_DASH: Regex = Regex::new(r"^(\-\s+){2,}\-\s*$").unwrap();
-    static ref HR_SPACED_ASTERISK: Regex = Regex::new(r"^(\*\s+){2,}\*\s*$").unwrap();
-    static ref HR_SPACED_UNDERSCORE: Regex = Regex::new(r"^(_\s+){2,}_\s*$").unwrap();
-}
-
 #[derive(Clone, Default)]
 pub struct MD025SingleTitle {
     config: MD025Config,
@@ -110,8 +98,8 @@ impl MD025SingleTitle {
             lower_text.contains(&format!(" {indicator}")) ||
             // Handle appendix numbering like "Appendix A", "Appendix 1"
             (indicator == "appendix" && (
-                lower_text.matches("appendix").count() == 1 && 
-                (lower_text.contains(" a") || lower_text.contains(" b") || 
+                lower_text.matches("appendix").count() == 1 &&
+                (lower_text.contains(" a") || lower_text.contains(" b") ||
                  lower_text.contains(" 1") || lower_text.contains(" 2") ||
                  lower_text.contains(" i") || lower_text.contains(" ii"))
             ))
@@ -379,7 +367,9 @@ impl Rule for MD025SingleTitle {
                                 // For empty headings, manually construct the replacement
                                 match style {
                                     crate::rules::heading_utils::HeadingStyle::Atx
-                                    | crate::rules::heading_utils::HeadingStyle::SetextWithAtx => "#".repeat(self.config.level + 1),
+                                    | crate::rules::heading_utils::HeadingStyle::SetextWithAtx => {
+                                        "#".repeat(self.config.level + 1)
+                                    }
                                     crate::rules::heading_utils::HeadingStyle::AtxClosed
                                     | crate::rules::heading_utils::HeadingStyle::SetextWithAtxClosed => {
                                         format!(
@@ -450,10 +440,40 @@ impl Rule for MD025SingleTitle {
         RuleCategory::Heading
     }
 
-    /// Check if this rule should be skipped
+    /// Check if this rule should be skipped for performance
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
-        ctx.content.is_empty()
-            || (!ctx.content.contains('#') && !ctx.content.contains('=') && !ctx.content.contains('-'))
+        // Skip if content is empty
+        if ctx.content.is_empty() {
+            return true;
+        }
+
+        // Skip if no heading markers at all
+        if !ctx.content.contains('#') && !ctx.content.contains('=') && !ctx.content.contains('-') {
+            return true;
+        }
+
+        // Fast path: count target level headings efficiently
+        let mut target_level_count = 0;
+        for line_info in &ctx.lines {
+            if let Some(heading) = &line_info.heading {
+                if heading.level as usize == self.config.level {
+                    // Ignore if indented 4+ spaces (code block)
+                    if line_info.indent >= 4 {
+                        continue;
+                    }
+                    target_level_count += 1;
+
+                    // If we find more than 1, we need to run the full check
+                    // to determine if they're legitimate document sections
+                    if target_level_count > 1 {
+                        return false;
+                    }
+                }
+            }
+        }
+
+        // If we have 0 or 1 target level headings, skip the rule
+        target_level_count <= 1
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
