@@ -239,7 +239,7 @@ impl MD033NoInlineHtml {
                                     column: start_col,
                                     end_line,
                                     end_column: end_col,
-                                    message: format!("HTML tag found: {} (use Markdown syntax instead)", final_tag),
+                                    message: format!("HTML tag found: {final_tag} (use Markdown syntax instead)"),
                                     severity: Severity::Warning,
                                     fix: None,
                                 });
@@ -344,7 +344,7 @@ impl Rule for MD033NoInlineHtml {
                     column: start_col,
                     end_line,
                     end_column: end_col,
-                    message: format!("Inline HTML found: {} (use Markdown syntax instead)", tag),
+                    message: format!("Inline HTML found: {tag} (use Markdown syntax instead)"),
                     severity: Severity::Warning,
                     fix: None,
                 });
@@ -435,10 +435,22 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // Reports one warning per HTML tag (true markdownlint compatibility)
         assert_eq!(result.len(), 4); // <DiV>, <B>, </B>, </dIv>
-        assert_eq!(result[0].message, "Inline HTML found: <DiV> (use Markdown syntax instead)");
-        assert_eq!(result[1].message, "Inline HTML found: <B> (use Markdown syntax instead)");
-        assert_eq!(result[2].message, "Inline HTML found: </B> (use Markdown syntax instead)");
-        assert_eq!(result[3].message, "Inline HTML found: </dIv> (use Markdown syntax instead)");
+        assert_eq!(
+            result[0].message,
+            "Inline HTML found: <DiV> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result[1].message,
+            "Inline HTML found: <B> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result[2].message,
+            "Inline HTML found: </B> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result[3].message,
+            "Inline HTML found: </dIv> (use Markdown syntax instead)"
+        );
     }
 
     #[test]
@@ -449,16 +461,28 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // Only warnings for non-allowed tags (<p> and </p>, div and br are allowed)
         assert_eq!(result.len(), 2);
-        assert_eq!(result[0].message, "Inline HTML found: <p> (use Markdown syntax instead)");
-        assert_eq!(result[1].message, "Inline HTML found: </p> (use Markdown syntax instead)");
+        assert_eq!(
+            result[0].message,
+            "Inline HTML found: <p> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result[1].message,
+            "Inline HTML found: </p> (use Markdown syntax instead)"
+        );
 
         // Test case-insensitivity of allowed tags
         let content2 = "<DIV>Allowed</DIV><P>Not allowed</P><BR/>";
         let ctx2 = LintContext::new(content2);
         let result2 = rule.check(&ctx2).unwrap();
         assert_eq!(result2.len(), 2); // <P> and </P> flagged
-        assert_eq!(result2[0].message, "Inline HTML found: <P> (use Markdown syntax instead)");
-        assert_eq!(result2[1].message, "Inline HTML found: </P> (use Markdown syntax instead)");
+        assert_eq!(
+            result2[0].message,
+            "Inline HTML found: <P> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result2[1].message,
+            "Inline HTML found: </P> (use Markdown syntax instead)"
+        );
     }
 
     #[test]
@@ -469,8 +493,14 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // Should detect warnings for HTML tags (comments are skipped)
         assert_eq!(result.len(), 2); // <p> and </p>
-        assert_eq!(result[0].message, "Inline HTML found: <p> (use Markdown syntax instead)");
-        assert_eq!(result[1].message, "Inline HTML found: </p> (use Markdown syntax instead)");
+        assert_eq!(
+            result[0].message,
+            "Inline HTML found: <p> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result[1].message,
+            "Inline HTML found: </p> (use Markdown syntax instead)"
+        );
     }
 
     #[test]
@@ -481,15 +511,24 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // The <div> in the URL should be detected as HTML (not skipped)
         assert_eq!(result.len(), 1);
-        assert_eq!(result[0].message, "Inline HTML found: <div> (use Markdown syntax instead)");
+        assert_eq!(
+            result[0].message,
+            "Inline HTML found: <div> (use Markdown syntax instead)"
+        );
 
         let content2 = "[Link <a>text</a>](url)";
         let ctx2 = LintContext::new(content2);
         let result2 = rule.check(&ctx2).unwrap();
         // Reports one warning per HTML tag (true markdownlint compatibility)
         assert_eq!(result2.len(), 2); // <a> and </a>
-        assert_eq!(result2[0].message, "Inline HTML found: <a> (use Markdown syntax instead)");
-        assert_eq!(result2[1].message, "Inline HTML found: </a> (use Markdown syntax instead)");
+        assert_eq!(
+            result2[0].message,
+            "Inline HTML found: <a> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result2[1].message,
+            "Inline HTML found: </a> (use Markdown syntax instead)"
+        );
     }
 
     #[test]
@@ -510,8 +549,14 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // Reports one warning per HTML tag (true markdownlint compatibility)
         assert_eq!(result.len(), 2); // <div> and </div> outside code block
-        assert_eq!(result[0].message, "Inline HTML found: <div> (use Markdown syntax instead)");
-        assert_eq!(result[1].message, "Inline HTML found: </div> (use Markdown syntax instead)");
+        assert_eq!(
+            result[0].message,
+            "Inline HTML found: <div> (use Markdown syntax instead)"
+        );
+        assert_eq!(
+            result[1].message,
+            "Inline HTML found: </div> (use Markdown syntax instead)"
+        );
     }
 
     #[test]
@@ -522,6 +567,9 @@ mod tests {
         let result = rule.check(&ctx).unwrap();
         // Should detect <br/> outside code span, but not tags inside code span
         assert_eq!(result.len(), 1);
-        assert_eq!(result[0].message, "Inline HTML found: <br/> (use Markdown syntax instead)");
+        assert_eq!(
+            result[0].message,
+            "Inline HTML found: <br/> (use Markdown syntax instead)"
+        );
     }
 }
